@@ -9,6 +9,7 @@
 Defines types for manipulation of units and quantities without phantom types for their dimensions.
 -}
 
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveGeneric #-}
@@ -35,8 +36,11 @@ module Numeric.Units.Dimensional.Dynamic
 , (*), (/), (^), recip, applyPrefix
 ) where
 
-import Control.DeepSeq
+import Control.DeepSeq (NFData)
 import Control.Monad
+#if USE_BINARY
+import qualified Data.Binary
+#endif
 import Data.Data
 import Data.ExactPi
 import Data.Kind
@@ -115,6 +119,10 @@ instance Num a => Monoid (AnyQuantity a) where
   mempty = demoteQuantity (1 Dim.*~ one)
   mappend = (<>)
 
+#if USE_BINARY
+instance (Data.Binary.Binary a) => Data.Binary.Binary (AnyQuantity a)
+#endif
+
 -- | Possibly a 'Quantity' whose 'Dimension' is only known dynamically.
 --
 -- By modeling the absence of a value, this type differs from 'AnyQuantity' in that it may
@@ -194,6 +202,10 @@ instance Num a => Monoid (DynQuantity a) where
   mempty = demoteQuantity (1 Dim.*~ one)
   mappend = (<>)
 
+#if USE_BINARY
+instance (Data.Binary.Binary a) => Data.Binary.Binary (DynQuantity a)
+#endif
+
 -- | A 'DynQuantity' which does not correspond to a value of any dimension.
 invalidQuantity :: DynQuantity a
 invalidQuantity = DynQuantity NoDimension $ error "Attempt to evaluate the value of an invalid quantity."
