@@ -26,8 +26,11 @@ module Numeric.Units.Dimensional.Internal
 where
 
 import Control.Applicative
-import Control.DeepSeq
+import Control.DeepSeq (NFData)
 import Data.AEq (AEq)
+#if USE_BINARY
+import qualified Data.Binary
+#endif
 import Data.Coerce (coerce)
 import Data.Data
 import Data.Kind
@@ -57,6 +60,7 @@ import qualified Prelude as P
 
 -- $setup
 -- >>> :set -XNoImplicitPrelude
+-- >>> :set -fno-warn-type-defaults
 -- >>> import Numeric.Units.Dimensional.Prelude
 
 -- | A unit of measurement.
@@ -137,6 +141,10 @@ instance (Num a) => Monoid (SQuantity s d a) where
   mempty = Quantity 0
   mappend = (<>)
 
+#if USE_BINARY
+deriving instance (Data.Binary.Binary a) => Data.Binary.Binary (SQuantity s d a)
+#endif
+
 {-
 
 = Dimensionless =
